"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    service_id: str,
    dry_run: bool = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the principals (service consumers) that are permitted to discover your VPC endpoint service.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        service_id(str): The ID of the service.
        filters(List, optional): One or more filters.    principal - The ARN of the principal.    principal-type - The principal type (All | Service | OrganizationUnit | Account | User | Role).  . Defaults to None.
        max_results(int, optional): The maximum number of results to return for the request in a single page. The remaining results of the initial request can be seen by sending another request with the returned NextToken value. This value can be between 5 and 1,000; if MaxResults is given a value larger than 1,000, only 1,000 results are returned. Defaults to None.
        next_token(str, optional): The token to retrieve the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpc.endpoint.service.permission.describe_all(
                ctx, service_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpc.endpoint.service.permission.describe_all service_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_vpc_endpoint_service_permissions",
        op_kwargs={
            "DryRun": dry_run,
            "ServiceId": service_id,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def modify(
    hub,
    ctx,
    service_id: str,
    dry_run: bool = None,
    add_allowed_principals: List = None,
    remove_allowed_principals: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the permissions for your VPC endpoint service. You can add or remove permissions for service consumers (IAM users, IAM roles, and AWS accounts) to connect to your endpoint service. If you grant permissions to all principals, the service is public. Any users who know the name of a public service can send a request to attach an endpoint. If the service does not require manual approval, attachments are automatically approved.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        service_id(str): The ID of the service.
        add_allowed_principals(List, optional): The Amazon Resource Names (ARN) of one or more principals. Permissions are granted to the principals in this list. To grant permissions to all principals, specify an asterisk (*). Defaults to None.
        remove_allowed_principals(List, optional): The Amazon Resource Names (ARN) of one or more principals. Permissions are revoked for principals in this list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpc.endpoint.service.permission.modify(
                ctx, service_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpc.endpoint.service.permission.modify service_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="modify_vpc_endpoint_service_permissions",
        op_kwargs={
            "DryRun": dry_run,
            "ServiceId": service_id,
            "AddAllowedPrincipals": add_allowed_principals,
            "RemoveAllowedPrincipals": remove_allowed_principals,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    load_balancer_name: str,
    policy_name: str,
    cookie_expiration_period: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Generates a stickiness policy with sticky session lifetimes controlled by the lifetime of the browser (user-agent) or a specified expiration period. This policy can be associated only with HTTP/HTTPS listeners. When a load balancer implements this policy, the load balancer uses a special cookie to track the instance for each request. When the load balancer receives a request, it first checks to see if this cookie is present in the request. If so, the load balancer sends the request to the application server specified in the cookie. If not, the load balancer sends the request to a server that is chosen based on the existing load-balancing algorithm. A cookie is inserted into the response for binding subsequent requests from the same user to that server. The validity of the cookie is based on the cookie expiration time, which is specified in the policy configuration. For more information, see Duration-Based Session Stickiness in the Classic Load Balancers Guide.

    Args:
        load_balancer_name(str): The name of the load balancer.
        policy_name(str): The name of the policy being created. Policy names must consist of alphanumeric characters and dashes (-). This name must be unique within the set of policies for this load balancer.
        cookie_expiration_period(int, optional): The time period, in seconds, after which the cookie should be considered stale. If you do not specify this parameter, the default value is 0, which indicates that the sticky session should last for the duration of the browser session. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elb.lb_cookie_stickiness_policy.create(
                ctx, load_balancer_name=value, policy_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elb.lb_cookie_stickiness_policy.create load_balancer_name=value, policy_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elb",
        operation="create_lb_cookie_stickiness_policy",
        op_kwargs={
            "LoadBalancerName": load_balancer_name,
            "PolicyName": policy_name,
            "CookieExpirationPeriod": cookie_expiration_period,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, aws_service_name: str, description: str = None, custom_suffix: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an IAM role that is linked to a specific Amazon Web Services service. The service controls the attached policies and when the role can be deleted. This helps ensure that the service is not broken by an unexpectedly changed or deleted role, which could put your Amazon Web Services resources into an unknown state. Allowing the service to control the role helps improve service stability and proper cleanup when a service and its role are no longer needed. For more information, see Using service-linked roles in the IAM User Guide.  To attach a policy to this service-linked role, you must make the request using the Amazon Web Services service that depends on this role.

    Args:
        aws_service_name(str): The service principal for the Amazon Web Services service to which this role is attached. You use a string similar to a URL but without the http:// in front. For example: elasticbeanstalk.amazonaws.com.  Service principals are unique and case-sensitive. To find the exact service principal for your service-linked role, see Amazon Web Services services that work with IAM in the IAM User Guide. Look for the services that have Yes in the Service-Linked Role column. Choose the Yes link to view the service-linked role documentation for that service.
        description(str, optional): The description of the role. Defaults to None.
        custom_suffix(str, optional):  A string that you provide, which is combined with the service-provided prefix to form the complete role name. If you make multiple requests for the same service, then you must supply a different CustomSuffix for each request. Otherwise the request fails with a duplicate role name error. For example, you could add -1 or -debug to the suffix. Some services do not support the CustomSuffix parameter. If you provide an optional suffix and the operation fails, try the operation again without the suffix. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.service.linked_role.init.create(ctx, aws_service_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.service.linked_role.init.create aws_service_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="create_service_linked_role",
        op_kwargs={
            "AWSServiceName": aws_service_name,
            "Description": description,
            "CustomSuffix": custom_suffix,
        },
    )


async def delete(hub, ctx, role_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Submits a service-linked role deletion request and returns a DeletionTaskId, which you can use to check the status of the deletion. Before you call this operation, confirm that the role has no active sessions and that any resources used by the role in the linked service are deleted. If you call this operation more than once for the same service-linked role and an earlier deletion task is not complete, then the DeletionTaskId of the earlier request is returned. If you submit a deletion request for a service-linked role whose linked service is still accessing a resource, then the deletion task fails. If it fails, the GetServiceLinkedRoleDeletionStatus operation returns the reason for the failure, usually including the resources that must be deleted. To delete the service-linked role, you must first remove those resources from the linked service and then submit the deletion request again. Resources are specific to the service that is linked to the role. For more information about removing resources from a service, see the Amazon Web Services documentation for your service. For more information about service-linked roles, see Roles terms and concepts: Amazon Web Services service-linked role in the IAM User Guide.

    Args:
        role_name(str): The name of the service-linked role to be deleted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.service.linked_role.init.delete(ctx, role_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.service.linked_role.init.delete role_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="delete_service_linked_role",
        op_kwargs={"RoleName": role_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, name: str, description: str = None, tags: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    An application in AppConfig is a logical unit of code that provides capabilities for your customers. For example, an application can be a microservice that runs on Amazon EC2 instances, a mobile application installed by your users, a serverless application using Amazon API Gateway and AWS Lambda, or any system you run on behalf of others.

    Args:
        name(str): A name for the application.
        description(str, optional): A description of the application. Defaults to None.
        tags(Dict, optional): Metadata to assign to the application. Tags help organize and categorize your AppConfig resources. Each tag consists of a key and an optional value, both of which you define. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appconfig.application.create(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appconfig.application.create name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appconfig",
        operation="create_application",
        op_kwargs={"Name": name, "Description": description, "Tags": tags},
    )


async def delete(hub, ctx, application_id: str) -> None:
    r"""
    **Autogenerated function**

    Delete an application. Deleting an application does not delete a configuration from a host.

    Args:
        application_id(str): The ID of the application to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appconfig.application.delete(ctx, application_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appconfig.application.delete application_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appconfig",
        operation="delete_application",
        op_kwargs={"ApplicationId": application_id},
    )


async def get(hub, ctx, application_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieve information about an application.

    Args:
        application_id(str): The ID of the application you want to get.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appconfig.application.get(ctx, application_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appconfig.application.get application_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appconfig",
        operation="get_application",
        op_kwargs={"ApplicationId": application_id},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    List all applications in your AWS account.

    Args:
        max_results(int, optional): The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results. Defaults to None.
        next_token(str, optional): A token to start the list. Use this token to get the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appconfig.application.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appconfig.application.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appconfig",
        operation="list_applications",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def update(
    hub, ctx, application_id: str, name: str = None, description: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an application.

    Args:
        application_id(str): The application ID.
        name(str, optional): The name of the application. Defaults to None.
        description(str, optional): A description of the application. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appconfig.application.update(ctx, application_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appconfig.application.update application_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appconfig",
        operation="update_application",
        op_kwargs={
            "ApplicationId": application_id,
            "Name": name,
            "Description": description,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def deregister(hub, ctx, job_definition: str) -> Dict:
    r"""
    **Autogenerated function**

    Deregisters an Batch job definition. Job definitions are permanently deleted after 180 days.

    Args:
        job_definition(str): The name and revision (name:revision) or full Amazon Resource Name (ARN) of the job definition to deregister.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.batch.job.definition.deregister(ctx, job_definition=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.batch.job.definition.deregister job_definition=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="batch",
        operation="deregister_job_definition",
        op_kwargs={"jobDefinition": job_definition},
    )


async def describe_all(
    hub,
    ctx,
    job_definitions: List = None,
    max_results: int = None,
    job_definition_name: str = None,
    status: str = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes a list of job definitions. You can specify a status (such as ACTIVE) to only return job definitions that match that status.

    Args:
        job_definitions(List, optional): A list of up to 100 job definitions. Each entry in the list can either be an ARN of the form arn:aws:batch:${Region}:${Account}:job-definition/${JobDefinitionName}:${Revision} or a short version using the form ${JobDefinitionName}:${Revision}. Defaults to None.
        max_results(int, optional): The maximum number of results returned by DescribeJobDefinitions in paginated output. When this parameter is used, DescribeJobDefinitions only returns maxResults results in a single page and a nextToken response element. The remaining results of the initial request can be seen by sending another DescribeJobDefinitions request with the returned nextToken value. This value can be between 1 and 100. If this parameter isn't used, then DescribeJobDefinitions returns up to 100 results and a nextToken value if applicable. Defaults to None.
        job_definition_name(str, optional): The name of the job definition to describe. Defaults to None.
        status(str, optional): The status used to filter job definitions. Defaults to None.
        next_token(str, optional): The nextToken value returned from a previous paginated DescribeJobDefinitions request where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value. This value is null when there are no more results to return.  This token should be treated as an opaque identifier that's only used to retrieve the next items in a list and not for other programmatic purposes. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.batch.job.definition.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.batch.job.definition.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="batch",
        operation="describe_job_definitions",
        op_kwargs={
            "jobDefinitions": job_definitions,
            "maxResults": max_results,
            "jobDefinitionName": job_definition_name,
            "status": status,
            "nextToken": next_token,
        },
    )


async def register(
    hub,
    ctx,
    job_definition_name: str,
    type_: str,
    parameters: Dict = None,
    container_properties: Dict = None,
    node_properties: Dict = None,
    retry_strategy: Dict = None,
    propagate_tags: bool = None,
    timeout: Dict = None,
    tags: Dict = None,
    platform_capabilities: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Registers an Batch job definition.

    Args:
        job_definition_name(str): The name of the job definition to register. Up to 128 letters (uppercase and lowercase), numbers, hyphens, and underscores are allowed.
        type_(str): The type of job definition. For more information about multi-node parallel jobs, see Creating a multi-node parallel job definition in the Batch User Guide.  If the job is run on Fargate resources, then multinode isn't supported. .
        parameters(Dict, optional): Default parameter substitution placeholders to set in the job definition. Parameters are specified as a key-value pair mapping. Parameters in a SubmitJob request override any corresponding parameter defaults from the job definition. Defaults to None.
        container_properties(Dict, optional): An object with various properties specific to single-node container-based jobs. If the job definition's type parameter is container, then you must specify either containerProperties or nodeProperties.  If the job runs on Fargate resources, then you must not specify nodeProperties; use only containerProperties. . Defaults to None.
        node_properties(Dict, optional): An object with various properties specific to multi-node parallel jobs. If you specify node properties for a job, it becomes a multi-node parallel job. For more information, see Multi-node Parallel Jobs in the Batch User Guide. If the job definition's type parameter is container, then you must specify either containerProperties or nodeProperties.  If the job runs on Fargate resources, then you must not specify nodeProperties; use containerProperties instead. . Defaults to None.
        retry_strategy(Dict, optional): The retry strategy to use for failed jobs that are submitted with this job definition. Any retry strategy that's specified during a SubmitJob operation overrides the retry strategy defined here. If a job is terminated due to a timeout, it isn't retried. Defaults to None.
        propagate_tags(bool, optional): Specifies whether to propagate the tags from the job or job definition to the corresponding Amazon ECS task. If no value is specified, the tags are not propagated. Tags can only be propagated to the tasks during task creation. For tags with the same name, job tags are given priority over job definitions tags. If the total number of combined tags from the job and job definition is over 50, the job is moved to the FAILED state. Defaults to None.
        timeout(Dict, optional): The timeout configuration for jobs that are submitted with this job definition, after which Batch terminates your jobs if they have not finished. If a job is terminated due to a timeout, it isn't retried. The minimum value for the timeout is 60 seconds. Any timeout configuration that's specified during a SubmitJob operation overrides the timeout configuration defined here. For more information, see Job Timeouts in the Batch User Guide. Defaults to None.
        tags(Dict, optional): The tags that you apply to the job definition to help you categorize and organize your resources. Each tag consists of a key and an optional value. For more information, see Tagging Amazon Web Services Resources in Batch User Guide. Defaults to None.
        platform_capabilities(List, optional): The platform capabilities required by the job definition. If no value is specified, it defaults to EC2. To run the job on Fargate resources, specify FARGATE. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.batch.job.definition.register(
                ctx, job_definition_name=value, type_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.batch.job.definition.register job_definition_name=value, type_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="batch",
        operation="register_job_definition",
        op_kwargs={
            "jobDefinitionName": job_definition_name,
            "type": type_,
            "parameters": parameters,
            "containerProperties": container_properties,
            "nodeProperties": node_properties,
            "retryStrategy": retry_strategy,
            "propagateTags": propagate_tags,
            "timeout": timeout,
            "tags": tags,
            "platformCapabilities": platform_capabilities,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub, ctx, export_ids: List = None, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists exports as specified by ID. All continuous exports associated with your user account can be listed if you call DescribeContinuousExports as is without passing any parameters.

    Args:
        export_ids(List, optional): The unique IDs assigned to the exports. Defaults to None.
        max_results(int, optional): A number between 1 and 100 specifying the maximum number of continuous export descriptions returned. Defaults to None.
        next_token(str, optional): The token from the previous call to DescribeExportTasks. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.discovery.continuous_export.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.discovery.continuous_export.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="discovery",
        operation="describe_continuous_exports",
        op_kwargs={
            "exportIds": export_ids,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )


async def start(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Start the continuous flow of agent's discovered data into Amazon Athena.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.discovery.continuous_export.start(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.discovery.continuous_export.start
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="discovery", operation="start_continuous_export", op_kwargs={}
    )


async def stop(hub, ctx, export_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Stop the continuous flow of agent's discovered data into Amazon Athena.

    Args:
        export_id(str): The unique ID assigned to this export.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.discovery.continuous_export.stop(ctx, export_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.discovery.continuous_export.stop export_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="discovery",
        operation="stop_continuous_export",
        op_kwargs={"exportId": export_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def subscribe(
    hub, ctx, arn: str, target: Dict, client_request_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an association between a notification rule and an SNS topic so that the associated target can receive notifications when the events described in the rule are triggered.

    Args:
        arn(str): The Amazon Resource Name (ARN) of the notification rule for which you want to create the association.
        target(Dict): Information about the SNS topics associated with a notification rule.
        client_request_token(str, optional): An enumeration token that, when provided in a request, returns the next batch of the results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codestar_notification.init.subscribe(
                ctx, arn=value, target=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codestar_notification.init.subscribe arn=value, target=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codestar-notifications",
        operation="subscribe",
        op_kwargs={
            "Arn": arn,
            "Target": target,
            "ClientRequestToken": client_request_token,
        },
    )


async def unsubscribe(hub, ctx, arn: str, target_address: str) -> Dict:
    r"""
    **Autogenerated function**

    Removes an association between a notification rule and an Amazon SNS topic so that subscribers to that topic stop receiving notifications when the events described in the rule are triggered.

    Args:
        arn(str): The Amazon Resource Name (ARN) of the notification rule.
        target_address(str): The ARN of the SNS topic to unsubscribe from the notification rule.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codestar_notification.init.unsubscribe(
                ctx, arn=value, target_address=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codestar_notification.init.unsubscribe arn=value, target_address=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codestar-notifications",
        operation="unsubscribe",
        op_kwargs={"Arn": arn, "TargetAddress": target_address},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(hub, ctx, identity_store_id: str, user_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the user metadata and attributes from UserId in an identity store.

    Args:
        identity_store_id(str): The globally unique identifier for the identity store, such as d-1234567890. In this example, d- is a fixed prefix, and 1234567890 is a randomly generated string that contains number and lower case letters. This value is generated at the time that a new identity store is created.
        user_id(str): The identifier for a user in the identity store.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.identitystore.user.describe(
                ctx, identity_store_id=value, user_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.identitystore.user.describe identity_store_id=value, user_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="identitystore",
        operation="describe_user",
        op_kwargs={"IdentityStoreId": identity_store_id, "UserId": user_id},
    )


async def list_all(
    hub,
    ctx,
    identity_store_id: str,
    max_results: int = None,
    next_token: str = None,
    filters: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the attribute name and value of the user that you specified in the search. We only support UserName as a valid filter attribute path currently, and filter is required. This API returns minimum attributes, including UserId and UserName in the response.

    Args:
        identity_store_id(str): The globally unique identifier for the identity store, such as d-1234567890. In this example, d- is a fixed prefix, and 1234567890 is a randomly generated string that contains number and lower case letters. This value is generated at the time that a new identity store is created.
        max_results(int, optional): The maximum number of results to be returned per request. This parameter is used in the ListUsers and ListGroups request to specify how many results to return in one page. The length limit is 50 characters. Defaults to None.
        next_token(str, optional): The pagination token used for the ListUsers and ListGroups API operations. This value is generated by the identity store service. It is returned in the API response if the total results are more than the size of one page. This token is also returned when it is used in the API request to search for the next page. Defaults to None.
        filters(List, optional): A list of Filter objects, which is used in the ListUsers and ListGroups request. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.identitystore.user.list_all(ctx, identity_store_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.identitystore.user.list_all identity_store_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="identitystore",
        operation="list_users",
        op_kwargs={
            "IdentityStoreId": identity_store_id,
            "MaxResults": max_results,
            "NextToken": next_token,
            "Filters": filters,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    bot_name: str,
    role_arn: str,
    data_privacy: Dict,
    idle_session_ttl_in_seconds: int,
    description: str = None,
    bot_tags: Dict = None,
    test_bot_alias_tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an Amazon Lex conversational bot.

    Args:
        bot_name(str): The name of the bot. The bot name must be unique in the account that creates the bot.
        description(str, optional): A description of the bot. It appears in lists to help you identify a particular bot. Defaults to None.
        role_arn(str): The Amazon Resource Name (ARN) of an IAM role that has permission to access the bot.
        data_privacy(Dict): Provides information on additional privacy protections Amazon Lex should use with the bot's data.
        idle_session_ttl_in_seconds(int): The time, in seconds, that Amazon Lex should keep information about a user's conversation with the bot.  A user interaction remains active for the amount of time specified. If no conversation occurs during this time, the session expires and Amazon Lex deletes any data provided before the timeout. You can specify between 60 (1 minute) and 86,400 (24 hours) seconds.
        bot_tags(Dict, optional): A list of tags to add to the bot. You can only add tags when you create a bot. You can't use the UpdateBot operation to update tags. To update tags, use the TagResource operation. Defaults to None.
        test_bot_alias_tags(Dict, optional): A list of tags to add to the test alias for a bot. You can only add tags when you create a bot. You can't use the UpdateAlias operation to update tags. To update tags on the test alias, use the TagResource operation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.bot.init.create(
                ctx,
                bot_name=value,
                role_arn=value,
                data_privacy=value,
                idle_session_ttl_in_seconds=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.bot.init.create bot_name=value, role_arn=value, data_privacy=value, idle_session_ttl_in_seconds=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="create_bot",
        op_kwargs={
            "botName": bot_name,
            "description": description,
            "roleArn": role_arn,
            "dataPrivacy": data_privacy,
            "idleSessionTTLInSeconds": idle_session_ttl_in_seconds,
            "botTags": bot_tags,
            "testBotAliasTags": test_bot_alias_tags,
        },
    )


async def delete(
    hub, ctx, bot_id: str, skip_resource_in_use_check: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes all versions of a bot, including the Draft version. To delete a specific version, use the DeleteBotVersion operation. When you delete a bot, all of the resources contained in the bot are also deleted. Deleting a bot removes all locales, intents, slot, and slot types defined for the bot. If a bot has an alias, the DeleteBot operation returns a ResourceInUseException exception. If you want to delete the bot and the alias, set the skipResourceInUseCheck parameter to true.

    Args:
        bot_id(str): The identifier of the bot to delete. .
        skip_resource_in_use_check(bool, optional): When true, Amazon Lex doesn't check to see if another resource, such as an alias, is using the bot before it is deleted. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.bot.init.delete(ctx, bot_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.bot.init.delete bot_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="delete_bot",
        op_kwargs={
            "botId": bot_id,
            "skipResourceInUseCheck": skip_resource_in_use_check,
        },
    )


async def describe(hub, ctx, bot_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Provides metadata information about a bot.

    Args:
        bot_id(str): The unique identifier of the bot to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.bot.init.describe(ctx, bot_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.bot.init.describe bot_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="describe_bot",
        op_kwargs={"botId": bot_id},
    )


async def update(
    hub,
    ctx,
    bot_id: str,
    bot_name: str,
    role_arn: str,
    data_privacy: Dict,
    idle_session_ttl_in_seconds: int,
    description: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the configuration of an existing bot.

    Args:
        bot_id(str): The unique identifier of the bot to update. This identifier is returned by the CreateBot operation.
        bot_name(str): The new name of the bot. The name must be unique in the account that creates the bot.
        description(str, optional): A description of the bot. Defaults to None.
        role_arn(str): The Amazon Resource Name (ARN) of an IAM role that has permissions to access the bot.
        data_privacy(Dict): Provides information on additional privacy protections Amazon Lex should use with the bot's data.
        idle_session_ttl_in_seconds(int): The time, in seconds, that Amazon Lex should keep information about a user's conversation with the bot. A user interaction remains active for the amount of time specified. If no conversation occurs during this time, the session expires and Amazon Lex deletes any data provided before the timeout. You can specify between 60 (1 minute) and 86,400 (24 hours) seconds.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.bot.init.update(
                ctx,
                bot_id=value,
                bot_name=value,
                role_arn=value,
                data_privacy=value,
                idle_session_ttl_in_seconds=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.bot.init.update bot_id=value, bot_name=value, role_arn=value, data_privacy=value, idle_session_ttl_in_seconds=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="update_bot",
        op_kwargs={
            "botId": bot_id,
            "botName": bot_name,
            "description": description,
            "roleArn": role_arn,
            "dataPrivacy": data_privacy,
            "idleSessionTTLInSeconds": idle_session_ttl_in_seconds,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, bucket: str, expected_bucket_owner: str = None) -> None:
    r"""
    **Autogenerated function**

    This implementation of the DELETE action removes default encryption from the bucket. For information about the Amazon S3 default encryption feature, see Amazon S3 Default Bucket Encryption in the Amazon S3 User Guide. To use this operation, you must have permissions to perform the s3:PutEncryptionConfiguration action. The bucket owner has this permission by default. The bucket owner can grant this permission to others. For more information about permissions, see Permissions Related to Bucket Subresource Operations and Managing Access Permissions to your Amazon S3 Resources in the Amazon S3 User Guide.  Related Resources     PutBucketEncryption     GetBucketEncryption

    Args:
        bucket(str): The name of the bucket containing the server-side encryption configuration to delete.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.encryption.delete(ctx, bucket=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.encryption.delete bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="delete_bucket_encryption",
        op_kwargs={"Bucket": bucket, "ExpectedBucketOwner": expected_bucket_owner},
    )


async def get(hub, ctx, bucket: str, expected_bucket_owner: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns the default encryption configuration for an Amazon S3 bucket. If the bucket does not have a default encryption configuration, GetBucketEncryption returns ServerSideEncryptionConfigurationNotFoundError.  For information about the Amazon S3 default encryption feature, see Amazon S3 Default Bucket Encryption.  To use this operation, you must have permission to perform the s3:GetEncryptionConfiguration action. The bucket owner has this permission by default. The bucket owner can grant this permission to others. For more information about permissions, see Permissions Related to Bucket Subresource Operations and Managing Access Permissions to Your Amazon S3 Resources. The following operations are related to GetBucketEncryption:    PutBucketEncryption     DeleteBucketEncryption

    Args:
        bucket(str): The name of the bucket from which the server-side encryption configuration is retrieved.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.encryption.get(ctx, bucket=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.encryption.get bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="get_bucket_encryption",
        op_kwargs={"Bucket": bucket, "ExpectedBucketOwner": expected_bucket_owner},
    )


async def put(
    hub,
    ctx,
    bucket: str,
    server_side_encryption_configuration: Dict,
    content_md5: str = None,
    expected_bucket_owner: str = None,
) -> None:
    r"""
    **Autogenerated function**

    This action uses the encryption subresource to configure default encryption and Amazon S3 Bucket Key for an existing bucket. Default encryption for a bucket can use server-side encryption with Amazon S3-managed keys (SSE-S3) or AWS KMS customer master keys (SSE-KMS). If you specify default encryption using SSE-KMS, you can also configure Amazon S3 Bucket Key. For information about default encryption, see Amazon S3 default bucket encryption in the Amazon S3 User Guide. For more information about S3 Bucket Keys, see Amazon S3 Bucket Keys in the Amazon S3 User Guide.  This action requires AWS Signature Version 4. For more information, see  Authenticating Requests (AWS Signature Version 4).   To use this operation, you must have permissions to perform the s3:PutEncryptionConfiguration action. The bucket owner has this permission by default. The bucket owner can grant this permission to others. For more information about permissions, see Permissions Related to Bucket Subresource Operations and Managing Access Permissions to Your Amazon S3 Resources in the Amazon S3 User Guide.   Related Resources     GetBucketEncryption     DeleteBucketEncryption

    Args:
        bucket(str): Specifies default encryption for a bucket using server-side encryption with Amazon S3-managed keys (SSE-S3) or customer master keys stored in AWS KMS (SSE-KMS). For information about the Amazon S3 default encryption feature, see Amazon S3 Default Bucket Encryption in the Amazon S3 User Guide.
        content_md5(str, optional): The base64-encoded 128-bit MD5 digest of the server-side encryption configuration. For requests made using the AWS Command Line Interface (CLI) or AWS SDKs, this field is calculated automatically. Defaults to None.
        server_side_encryption_configuration(Dict): Specifies the default server-side-encryption configuration.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.encryption.put(
                ctx, bucket=value, server_side_encryption_configuration=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.encryption.put bucket=value, server_side_encryption_configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="put_bucket_encryption",
        op_kwargs={
            "Bucket": bucket,
            "ContentMD5": content_md5,
            "ServerSideEncryptionConfiguration": server_side_encryption_configuration,
            "ExpectedBucketOwner": expected_bucket_owner,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    policy_name: str,
    policy_document: str,
    path: str = None,
    description: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new managed policy for your account. This operation creates a policy version with a version identifier of v1 and sets v1 as the policy's default version. For more information about policy versions, see Versioning for managed policies in the IAM User Guide. As a best practice, you can validate your IAM policies. To learn more, see Validating IAM policies in the IAM User Guide. For more information about managed policies in general, see Managed policies and inline policies in the IAM User Guide.

    Args:
        policy_name(str): The friendly name of the policy. IAM user, group, role, and policy names must be unique within the account. Names are not distinguished by case. For example, you cannot create resources named both "MyResource" and "myresource".
        path(str, optional): The path for the policy. For more information about paths, see IAM identifiers in the IAM User Guide. This parameter is optional. If it is not included, it defaults to a slash (/). This parameter allows (through its regex pattern) a string of characters consisting of either a forward slash (/) by itself or a string that must begin and end with forward slashes. In addition, it can contain any ASCII character from the ! (\u0021) through the DEL character (\u007F), including most punctuation characters, digits, and upper and lowercased letters. Defaults to None.
        policy_document(str): The JSON policy document that you want to use as the content for the new policy. You must provide policies in JSON format in IAM. However, for CloudFormation templates formatted in YAML, you can provide the policy in JSON or YAML format. CloudFormation always converts a YAML policy to JSON format before submitting it to IAM. The maximum length of the policy document that you can pass in this operation, including whitespace, is listed below. To view the maximum character counts of a managed policy with no whitespaces, see IAM and STS character quotas. To learn more about JSON policy grammar, see Grammar of the IAM JSON policy language in the IAM User Guide.  The regex pattern used to validate this parameter is a string of characters consisting of the following:   Any printable ASCII character ranging from the space character (\u0020) through the end of the ASCII character range   The printable characters in the Basic Latin and Latin-1 Supplement character set (through \u00FF)   The special characters tab (\u0009), line feed (\u000A), and carriage return (\u000D)  .
        description(str, optional): A friendly description of the policy. Typically used to store information about the permissions defined in the policy. For example, "Grants access to production DynamoDB tables." The policy description is immutable. After a value is assigned, it cannot be changed. Defaults to None.
        tags(List, optional): A list of tags that you want to attach to the new IAM customer managed policy. Each tag consists of a key name and an associated value. For more information about tagging, see Tagging IAM resources in the IAM User Guide.  If any one of the tags is invalid or if you exceed the allowed maximum number of tags, then the entire request fails and the resource is not created. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.policy.init.create(
                ctx, policy_name=value, policy_document=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.policy.init.create policy_name=value, policy_document=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="create_policy",
        op_kwargs={
            "PolicyName": policy_name,
            "Path": path,
            "PolicyDocument": policy_document,
            "Description": description,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, policy_arn: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified managed policy. Before you can delete a managed policy, you must first detach the policy from all users, groups, and roles that it is attached to. In addition, you must delete all the policy's versions. The following steps describe the process for deleting a managed policy:   Detach the policy from all users, groups, and roles that the policy is attached to, using DetachUserPolicy, DetachGroupPolicy, or DetachRolePolicy. To list all the users, groups, and roles that a policy is attached to, use ListEntitiesForPolicy.   Delete all versions of the policy using DeletePolicyVersion. To list the policy's versions, use ListPolicyVersions. You cannot use DeletePolicyVersion to delete the version that is marked as the default version. You delete the policy's default version in the next step of the process.   Delete the policy (this automatically deletes the policy's default version) using this operation.   For information about managed policies, see Managed policies and inline policies in the IAM User Guide.

    Args:
        policy_arn(str): The Amazon Resource Name (ARN) of the IAM policy you want to delete. For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.policy.init.delete(ctx, policy_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.policy.init.delete policy_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="delete_policy",
        op_kwargs={"PolicyArn": policy_arn},
    )


async def get(hub, ctx, policy_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about the specified managed policy, including the policy's default version and the total number of IAM users, groups, and roles to which the policy is attached. To retrieve the list of the specific users, groups, and roles that the policy is attached to, use ListEntitiesForPolicy. This operation returns metadata about the policy. To retrieve the actual policy document for a specific version of the policy, use GetPolicyVersion. This operation retrieves information about managed policies. To retrieve information about an inline policy that is embedded with an IAM user, group, or role, use GetUserPolicy, GetGroupPolicy, or GetRolePolicy. For more information about policies, see Managed policies and inline policies in the IAM User Guide.

    Args:
        policy_arn(str): The Amazon Resource Name (ARN) of the managed policy that you want information about. For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.policy.init.get(ctx, policy_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.policy.init.get policy_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="get_policy",
        op_kwargs={"PolicyArn": policy_arn},
    )


async def list_all(
    hub,
    ctx,
    scope: str = None,
    only_attached: bool = None,
    path_prefix: str = None,
    policy_usage_filter: str = None,
    marker: str = None,
    max_items: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all the managed policies that are available in your account, including your own customer-defined managed policies and all Amazon Web Services managed policies. You can filter the list of policies that is returned using the optional OnlyAttached, Scope, and PathPrefix parameters. For example, to list only the customer managed policies in your Amazon Web Services account, set Scope to Local. To list only Amazon Web Services managed policies, set Scope to AWS. You can paginate the results using the MaxItems and Marker parameters. For more information about managed policies, see Managed policies and inline policies in the IAM User Guide.  IAM resource-listing operations return a subset of the available attributes for the resource. For example, this operation does not return tags, even though they are an attribute of the returned object. To view all of the information for a customer manged policy, see GetPolicy.

    Args:
        scope(str, optional): The scope to use for filtering the results. To list only Amazon Web Services managed policies, set Scope to AWS. To list only the customer managed policies in your account, set Scope to Local. This parameter is optional. If it is not included, or if it is set to All, all policies are returned. Defaults to None.
        only_attached(bool, optional): A flag to filter the results to only the attached policies. When OnlyAttached is true, the returned list contains only the policies that are attached to an IAM user, group, or role. When OnlyAttached is false, or when the parameter is not included, all policies are returned. Defaults to None.
        path_prefix(str, optional): The path prefix for filtering the results. This parameter is optional. If it is not included, it defaults to a slash (/), listing all policies. This parameter allows (through its regex pattern) a string of characters consisting of either a forward slash (/) by itself or a string that must begin and end with forward slashes. In addition, it can contain any ASCII character from the ! (\u0021) through the DEL character (\u007F), including most punctuation characters, digits, and upper and lowercased letters. Defaults to None.
        policy_usage_filter(str, optional): The policy usage method to use for filtering the results. To list only permissions policies, set PolicyUsageFilter to PermissionsPolicy. To list only the policies used to set permissions boundaries, set the value to PermissionsBoundary. This parameter is optional. If it is not included, all policies are returned. . Defaults to None.
        marker(str, optional): Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated. Set it to the value of the Marker element in the response that you received to indicate where the next call should start. Defaults to None.
        max_items(int, optional): Use this only when paginating results to indicate the maximum number of items you want in the response. If additional items exist beyond the maximum you specify, the IsTruncated response element is true. If you do not include this parameter, the number of items defaults to 100. Note that IAM might return fewer results, even when there are more results available. In that case, the IsTruncated response element returns true, and Marker contains a value to include in the subsequent call that tells the service where to continue from. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.policy.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.policy.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="list_policies",
        op_kwargs={
            "Scope": scope,
            "OnlyAttached": only_attached,
            "PathPrefix": path_prefix,
            "PolicyUsageFilter": policy_usage_filter,
            "Marker": marker,
            "MaxItems": max_items,
        },
    )


async def tag(hub, ctx, policy_arn: str, tags: List) -> None:
    r"""
    **Autogenerated function**

    Adds one or more tags to an IAM customer managed policy. If a tag with the same key name already exists, then that tag is overwritten with the new value. A tag consists of a key name and an associated value. By assigning tags to your resources, you can do the following:    Administrative grouping and discovery - Attach tags to resources to aid in organization and search. For example, you could search for all resources with the key name Project and the value MyImportantProject. Or search for all resources with the key name Cost Center and the value 41200.     Access control - Include tags in IAM user-based and resource-based policies. You can use tags to restrict access to only an IAM customer managed policy that has a specified tag attached. For examples of policies that show how to use tags to control access, see Control access using IAM tags in the IAM User Guide.      If any one of the tags is invalid or if you exceed the allowed maximum number of tags, then the entire request fails and the resource is not created. For more information about tagging, see Tagging IAM resources in the IAM User Guide.   Amazon Web Services always interprets the tag Value as a single string. If you need to store an array, you can store comma-separated values in the string. However, you must interpret the value in your code.

    Args:
        policy_arn(str): The ARN of the IAM customer managed policy to which you want to add tags. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
        tags(List): The list of tags that you want to attach to the IAM customer managed policy. Each tag consists of a key name and an associated value.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.policy.init.tag(ctx, policy_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.policy.init.tag policy_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="tag_policy",
        op_kwargs={"PolicyArn": policy_arn, "Tags": tags},
    )


async def untag(hub, ctx, policy_arn: str, tag_keys: List) -> None:
    r"""
    **Autogenerated function**

    Removes the specified tags from the customer managed policy. For more information about tagging, see Tagging IAM resources in the IAM User Guide.

    Args:
        policy_arn(str): The ARN of the IAM customer managed policy from which you want to remove tags. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
        tag_keys(List): A list of key names as a simple array of strings. The tags with matching keys are removed from the specified policy.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.policy.init.untag(ctx, policy_arn=value, tag_keys=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.policy.init.untag policy_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="untag_policy",
        op_kwargs={"PolicyArn": policy_arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "partner_input"


async def create(
    hub, ctx, input_id: str, request_id: str = None, tags: Dict = None
) -> Dict:
    r"""
        **Autogenerated function**

        Create a partner input

        Args:
            input_id(str): Unique ID of the input.
            request_id(str, optional): Unique identifier of the request to ensure the request is handled
    exactly once in case of retries.
    . Defaults to None.
            tags(Dict, optional): A collection of key-value pairs. Defaults to None.

        Returns:
            Dict

        Examples:
            Call from code:

            .. code-block:: python

                await hub.exec.aws_auto.medialive.partner_input_.create(ctx, input_id=value)

            Call from CLI:

            .. code-block:: bash

                $ idem exec aws_auto.medialive.partner_input.create input_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="create_partner_input",
        op_kwargs={"InputId": input_id, "RequestId": request_id, "Tags": tags},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, transcription_job_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a previously submitted transcription job along with any other generated results such as the transcription, models, and so on.

    Args:
        transcription_job_name(str): The name of the transcription job to be deleted.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transcribe.transcription_job.delete(
                ctx, transcription_job_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transcribe.transcription_job.delete transcription_job_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transcribe",
        operation="delete_transcription_job",
        op_kwargs={"TranscriptionJobName": transcription_job_name},
    )


async def get(hub, ctx, transcription_job_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a transcription job. To see the status of the job, check the TranscriptionJobStatus field. If the status is COMPLETED, the job is finished and you can find the results at the location specified in the TranscriptFileUri field. If you enable content redaction, the redacted transcript appears in RedactedTranscriptFileUri.

    Args:
        transcription_job_name(str): The name of the job.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transcribe.transcription_job.get(
                ctx, transcription_job_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transcribe.transcription_job.get transcription_job_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transcribe",
        operation="get_transcription_job",
        op_kwargs={"TranscriptionJobName": transcription_job_name},
    )


async def list_all(
    hub,
    ctx,
    status: str = None,
    job_name_contains: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists transcription jobs with the specified status.

    Args:
        status(str, optional): When specified, returns only transcription jobs with the specified status. Jobs are ordered by creation date, with the newest jobs returned first. If you don’t specify a status, Amazon Transcribe returns all transcription jobs ordered by creation date. . Defaults to None.
        job_name_contains(str, optional): When specified, the jobs returned in the list are limited to jobs whose name contains the specified string. Defaults to None.
        next_token(str, optional): If the result of the previous request to ListTranscriptionJobs was truncated, include the NextToken to fetch the next set of jobs. Defaults to None.
        max_results(int, optional): The maximum number of jobs to return in the response. If there are fewer results in the list, this response contains only the actual results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transcribe.transcription_job.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transcribe.transcription_job.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transcribe",
        operation="list_transcription_jobs",
        op_kwargs={
            "Status": status,
            "JobNameContains": job_name_contains,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def start(
    hub,
    ctx,
    transcription_job_name: str,
    media: Dict,
    language_code: str = None,
    media_sample_rate_hertz: int = None,
    media_format: str = None,
    output_bucket_name: str = None,
    output_key: str = None,
    output_encryption_kms_key_id: str = None,
    settings: Dict = None,
    model_settings: Dict = None,
    job_execution_settings: Dict = None,
    content_redaction: Dict = None,
    identify_language: bool = None,
    language_options: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts an asynchronous job to transcribe speech to text.

    Args:
        transcription_job_name(str): The name of the job. You can't use the strings "." or ".." by themselves as the job name. The name must also be unique within an AWS account. If you try to create a transcription job with the same name as a previous transcription job, you get a ConflictException error.
        language_code(str, optional): The language code for the language used in the input media file. To transcribe speech in Modern Standard Arabic (ar-SA), your audio or video file must be encoded at a sample rate of 16000 Hz or higher. Defaults to None.
        media_sample_rate_hertz(int, optional): The sample rate, in Hertz, of the audio track in the input media file.  If you do not specify the media sample rate, Amazon Transcribe determines the sample rate. If you specify the sample rate, it must match the sample rate detected by Amazon Transcribe. In most cases, you should leave the MediaSampleRateHertz field blank and let Amazon Transcribe determine the sample rate. Defaults to None.
        media_format(str, optional): The format of the input media file. Defaults to None.
        media(Dict): An object that describes the input media for a transcription job.
        output_bucket_name(str, optional): The location where the transcription is stored. If you set the OutputBucketName, Amazon Transcribe puts the transcript in the specified S3 bucket. When you call the GetTranscriptionJob operation, the operation returns this location in the TranscriptFileUri field. If you enable content redaction, the redacted transcript appears in RedactedTranscriptFileUri. If you enable content redaction and choose to output an unredacted transcript, that transcript's location still appears in the TranscriptFileUri. The S3 bucket must have permissions that allow Amazon Transcribe to put files in the bucket. For more information, see Permissions Required for IAM User Roles. You can specify an AWS Key Management Service (KMS) key to encrypt the output of your transcription using the OutputEncryptionKMSKeyId parameter. If you don't specify a KMS key, Amazon Transcribe uses the default Amazon S3 key for server-side encryption of transcripts that are placed in your S3 bucket. If you don't set the OutputBucketName, Amazon Transcribe generates a pre-signed URL, a shareable URL that provides secure access to your transcription, and returns it in the TranscriptFileUri field. Use this URL to download the transcription. Defaults to None.
        output_key(str, optional): You can specify a location in an Amazon S3 bucket to store the output of your transcription job. If you don't specify an output key, Amazon Transcribe stores the output of your transcription job in the Amazon S3 bucket you specified. By default, the object key is "your-transcription-job-name.json". You can use output keys to specify the Amazon S3 prefix and file name of the transcription output. For example, specifying the Amazon S3 prefix, "folder1/folder2/", as an output key would lead to the output being stored as "folder1/folder2/your-transcription-job-name.json". If you specify "my-other-job-name.json" as the output key, the object key is changed to "my-other-job-name.json". You can use an output key to change both the prefix and the file name, for example "folder/my-other-job-name.json". If you specify an output key, you must also specify an S3 bucket in the OutputBucketName parameter. Defaults to None.
        output_encryption_kms_key_id(str, optional): The Amazon Resource Name (ARN) of the AWS Key Management Service (KMS) key used to encrypt the output of the transcription job. The user calling the StartTranscriptionJob operation must have permission to use the specified KMS key. You can use either of the following to identify a KMS key in the current account:   KMS Key ID: "1234abcd-12ab-34cd-56ef-1234567890ab"   KMS Key Alias: "alias/ExampleAlias"   You can use either of the following to identify a KMS key in the current account or another account:   Amazon Resource Name (ARN) of a KMS Key: "arn:aws:kms:region:account ID:key/1234abcd-12ab-34cd-56ef-1234567890ab"   ARN of a KMS Key Alias: "arn:aws:kms:region:account ID:alias/ExampleAlias"   If you don't specify an encryption key, the output of the transcription job is encrypted with the default Amazon S3 key (SSE-S3).  If you specify a KMS key to encrypt your output, you must also specify an output location in the OutputBucketName parameter. Defaults to None.
        settings(Dict, optional): A Settings object that provides optional settings for a transcription job. Defaults to None.
        model_settings(Dict, optional): Choose the custom language model you use for your transcription job in this parameter. Defaults to None.
        job_execution_settings(Dict, optional): Provides information about how a transcription job is executed. Use this field to indicate that the job can be queued for deferred execution if the concurrency limit is reached and there are no slots available to immediately run the job. Defaults to None.
        content_redaction(Dict, optional): An object that contains the request parameters for content redaction. Defaults to None.
        identify_language(bool, optional): Set this field to true to enable automatic language identification. Automatic language identification is disabled by default. You receive a BadRequestException error if you enter a value for a LanguageCode. Defaults to None.
        language_options(List, optional): An object containing a list of languages that might be present in your collection of audio files. Automatic language identification chooses a language that best matches the source audio from that list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transcribe.transcription_job.start(
                ctx, transcription_job_name=value, media=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transcribe.transcription_job.start transcription_job_name=value, media=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transcribe",
        operation="start_transcription_job",
        op_kwargs={
            "TranscriptionJobName": transcription_job_name,
            "LanguageCode": language_code,
            "MediaSampleRateHertz": media_sample_rate_hertz,
            "MediaFormat": media_format,
            "Media": media,
            "OutputBucketName": output_bucket_name,
            "OutputKey": output_key,
            "OutputEncryptionKMSKeyId": output_encryption_kms_key_id,
            "Settings": settings,
            "ModelSettings": model_settings,
            "JobExecutionSettings": job_execution_settings,
            "ContentRedaction": content_redaction,
            "IdentifyLanguage": identify_language,
            "LanguageOptions": language_options,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    application_name: str,
    role_arn: str,
    application_description: str = None,
    client_token: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a Fleet Hub for AWS IoT Device Management web application.  Fleet Hub for AWS IoT Device Management is in public preview and is subject to change.

    Args:
        application_name(str): The name of the web application.
        application_description(str, optional): An optional description of the web application. Defaults to None.
        client_token(str, optional): A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required. Defaults to None.
        role_arn(str): The ARN of the role that the web application assumes when it interacts with AWS IoT Core.  The name of the role must be in the form AWSIotFleetHub_random_string . .
        tags(Dict, optional): A set of key/value pairs that you can use to manage the web application resource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotfleethub.application.create(
                ctx, application_name=value, role_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotfleethub.application.create application_name=value, role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotfleethub",
        operation="create_application",
        op_kwargs={
            "applicationName": application_name,
            "applicationDescription": application_description,
            "clientToken": client_token,
            "roleArn": role_arn,
            "tags": tags,
        },
    )


async def delete(hub, ctx, application_id: str, client_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a Fleet Hub for AWS IoT Device Management web application.  Fleet Hub for AWS IoT Device Management is in public preview and is subject to change.

    Args:
        application_id(str): The unique Id of the web application.
        client_token(str, optional): A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotfleethub.application.delete(ctx, application_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotfleethub.application.delete application_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotfleethub",
        operation="delete_application",
        op_kwargs={"applicationId": application_id, "clientToken": client_token},
    )


async def describe(hub, ctx, application_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a Fleet Hub for AWS IoT Device Management web application.  Fleet Hub for AWS IoT Device Management is in public preview and is subject to change.

    Args:
        application_id(str): The unique Id of the web application.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotfleethub.application.describe(ctx, application_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotfleethub.application.describe application_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotfleethub",
        operation="describe_application",
        op_kwargs={"applicationId": application_id},
    )


async def list_all(hub, ctx, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of Fleet Hub for AWS IoT Device Management web applications for the current account.  Fleet Hub for AWS IoT Device Management is in public preview and is subject to change.

    Args:
        next_token(str, optional): A token used to get the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotfleethub.application.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotfleethub.application.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotfleethub",
        operation="list_applications",
        op_kwargs={"nextToken": next_token},
    )


async def update(
    hub,
    ctx,
    application_id: str,
    application_name: str = None,
    application_description: str = None,
    client_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates information about a Fleet Hub for a AWS IoT Device Management web application.  Fleet Hub for AWS IoT Device Management is in public preview and is subject to change.

    Args:
        application_id(str): The unique Id of the web application.
        application_name(str, optional): The name of the web application. Defaults to None.
        application_description(str, optional): An optional description of the web application. Defaults to None.
        client_token(str, optional): A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotfleethub.application.update(ctx, application_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotfleethub.application.update application_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotfleethub",
        operation="update_application",
        op_kwargs={
            "applicationId": application_id,
            "applicationName": application_name,
            "applicationDescription": application_description,
            "clientToken": client_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def put(hub, ctx, replication_configuration: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Creates or updates the replication configuration for a registry. The existing replication configuration for a repository can be retrieved with the DescribeRegistry API action. The first time the PutReplicationConfiguration API is called, a service-linked IAM role is created in your account for the replication process. For more information, see Using Service-Linked Roles for Amazon ECR in the Amazon Elastic Container Registry User Guide.  When configuring cross-account replication, the destination account must grant the source account permission to replicate. This permission is controlled using a registry permissions policy. For more information, see PutRegistryPolicy.

    Args:
        replication_configuration(Dict): An object representing the replication configuration for a registry.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecr.replication_configuration.put(
                ctx, replication_configuration=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecr.replication_configuration.put replication_configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecr",
        operation="put_replication_configuration",
        op_kwargs={"replicationConfiguration": replication_configuration},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(hub, ctx, resource_arns: List) -> Dict:
    r"""
    **Autogenerated function**

    Describes the tags associated with the specified Direct Connect resources.

    Args:
        resource_arns(List): The Amazon Resource Names (ARNs) of the resources.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.tags.describe(ctx, resource_arns=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.tags.describe resource_arns=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="describe_tags",
        op_kwargs={"resourceArns": resource_arns},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def add(hub, ctx, group_name: str, user_name: str) -> None:
    r"""
    **Autogenerated function**

    Adds the specified user to the specified group.

    Args:
        group_name(str): The name of the group to update. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
        user_name(str): The name of the user to add. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.user.to_group.add(ctx, group_name=value, user_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.user.to_group.add group_name=value, user_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="add_user_to_group",
        op_kwargs={"GroupName": group_name, "UserName": user_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub, ctx, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns details for a public registry.

    Args:
        next_token(str, optional): The nextToken value returned from a previous paginated DescribeRegistries request where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value. This value is null when there are no more results to return.  This token should be treated as an opaque identifier that is only used to retrieve the next items in a list and not for other programmatic purposes. . Defaults to None.
        max_results(int, optional): The maximum number of repository results returned by DescribeRegistries in paginated output. When this parameter is used, DescribeRegistries only returns maxResults results in a single page along with a nextToken response element. The remaining results of the initial request can be seen by sending another DescribeRegistries request with the returned nextToken value. This value can be between 1 and 1000. If this parameter is not used, then DescribeRegistries returns up to 100 results and a nextToken value, if applicable. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecr_public.registry.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecr_public.registry.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecr-public",
        operation="describe_registries",
        op_kwargs={"nextToken": next_token, "maxResults": max_results},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def disassociate(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    (Deprecated) Disassociates a member account from its Amazon Macie administrator account. This operation has been replaced by the DisassociateFromAdministratorAccount operation.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.from_.master_account.disassociate(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.from_.master_account.disassociate
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="disassociate_from_master_account",
        op_kwargs={},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(hub, ctx, domain: str, execution: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the specified workflow execution including its type and some statistics.  This operation is eventually consistent. The results are best effort and may not exactly reflect recent updates and changes.   Access Control  You can use IAM policies to control this action's access to Amazon SWF resources as follows:   Use a Resource element with the domain name to limit the action to only specified domains.   Use an Action element to allow or deny permission to call this action.   You cannot use an IAM policy to constrain this action's parameters.   If the caller doesn't have sufficient permissions to invoke the action, or the parameter values fall outside the specified constraints, the action fails. The associated event attribute's cause parameter is set to OPERATION_NOT_PERMITTED. For details and example IAM policies, see Using IAM to Manage Access to Amazon SWF Workflows in the Amazon SWF Developer Guide.

    Args:
        domain(str): The name of the domain containing the workflow execution.
        execution(Dict): The workflow execution to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.swf.workflow.execution.init.describe(
                ctx, domain=value, execution=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.swf.workflow.execution.init.describe domain=value, execution=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="swf",
        operation="describe_workflow_execution",
        op_kwargs={"domain": domain, "execution": execution},
    )


async def signal(
    hub,
    ctx,
    domain: str,
    workflow_id: str,
    signal_name: str,
    run_id: str = None,
    input_: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Records a WorkflowExecutionSignaled event in the workflow execution history and creates a decision task for the workflow execution identified by the given domain, workflowId and runId. The event is recorded with the specified user defined signalName and input (if provided).  If a runId isn't specified, then the WorkflowExecutionSignaled event is recorded in the history of the current open workflow with the matching workflowId in the domain.   If the specified workflow execution isn't open, this method fails with UnknownResource.   Access Control  You can use IAM policies to control this action's access to Amazon SWF resources as follows:   Use a Resource element with the domain name to limit the action to only specified domains.   Use an Action element to allow or deny permission to call this action.   You cannot use an IAM policy to constrain this action's parameters.   If the caller doesn't have sufficient permissions to invoke the action, or the parameter values fall outside the specified constraints, the action fails. The associated event attribute's cause parameter is set to OPERATION_NOT_PERMITTED. For details and example IAM policies, see Using IAM to Manage Access to Amazon SWF Workflows in the Amazon SWF Developer Guide.

    Args:
        domain(str): The name of the domain containing the workflow execution to signal.
        workflow_id(str): The workflowId of the workflow execution to signal.
        run_id(str, optional): The runId of the workflow execution to signal. Defaults to None.
        signal_name(str): The name of the signal. This name must be meaningful to the target workflow.
        input_(str, optional): Data to attach to the WorkflowExecutionSignaled event in the target workflow execution's history. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.swf.workflow.execution.init.signal(
                ctx, domain=value, workflow_id=value, signal_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.swf.workflow.execution.init.signal domain=value, workflow_id=value, signal_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="swf",
        operation="signal_workflow_execution",
        op_kwargs={
            "domain": domain,
            "workflowId": workflow_id,
            "runId": run_id,
            "signalName": signal_name,
            "input": input_,
        },
    )


async def start(
    hub,
    ctx,
    domain: str,
    workflow_id: str,
    workflow_type: Dict,
    task_list: Dict = None,
    task_priority: str = None,
    input_: str = None,
    execution_start_to_close_timeout: str = None,
    tag_list: List = None,
    task_start_to_close_timeout: str = None,
    child_policy: str = None,
    lambda_role: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts an execution of the workflow type in the specified domain using the provided workflowId and input data. This action returns the newly started workflow execution.  Access Control  You can use IAM policies to control this action's access to Amazon SWF resources as follows:   Use a Resource element with the domain name to limit the action to only specified domains.   Use an Action element to allow or deny permission to call this action.   Constrain the following parameters by using a Condition element with the appropriate keys.    tagList.member.0: The key is swf:tagList.member.0.    tagList.member.1: The key is swf:tagList.member.1.    tagList.member.2: The key is swf:tagList.member.2.    tagList.member.3: The key is swf:tagList.member.3.    tagList.member.4: The key is swf:tagList.member.4.    taskList: String constraint. The key is swf:taskList.name.    workflowType.name: String constraint. The key is swf:workflowType.name.    workflowType.version: String constraint. The key is swf:workflowType.version.     If the caller doesn't have sufficient permissions to invoke the action, or the parameter values fall outside the specified constraints, the action fails. The associated event attribute's cause parameter is set to OPERATION_NOT_PERMITTED. For details and example IAM policies, see Using IAM to Manage Access to Amazon SWF Workflows in the Amazon SWF Developer Guide.

    Args:
        domain(str): The name of the domain in which the workflow execution is created.
        workflow_id(str): The user defined identifier associated with the workflow execution. You can use this to associate a custom identifier with the workflow execution. You may specify the same identifier if a workflow execution is logically a restart of a previous execution. You cannot have two open workflow executions with the same workflowId at the same time within the same domain. The specified string must not start or end with whitespace. It must not contain a : (colon), / (slash), | (vertical bar), or any control characters (\u0000-\u001f | \u007f-\u009f). Also, it must not be the literal string arn.
        workflow_type(Dict): The type of the workflow to start.
        task_list(Dict, optional): The task list to use for the decision tasks generated for this workflow execution. This overrides the defaultTaskList specified when registering the workflow type.  A task list for this workflow execution must be specified either as a default for the workflow type or through this parameter. If neither this parameter is set nor a default task list was specified at registration time then a fault is returned.  The specified string must not start or end with whitespace. It must not contain a : (colon), / (slash), | (vertical bar), or any control characters (\u0000-\u001f | \u007f-\u009f). Also, it must not be the literal string arn. Defaults to None.
        task_priority(str, optional): The task priority to use for this workflow execution. This overrides any default priority that was assigned when the workflow type was registered. If not set, then the default task priority for the workflow type is used. Valid values are integers that range from Java's Integer.MIN_VALUE (-2147483648) to Integer.MAX_VALUE (2147483647). Higher numbers indicate higher priority. For more information about setting task priority, see Setting Task Priority in the Amazon SWF Developer Guide. Defaults to None.
        input_(str, optional): The input for the workflow execution. This is a free form string which should be meaningful to the workflow you are starting. This input is made available to the new workflow execution in the WorkflowExecutionStarted history event. Defaults to None.
        execution_start_to_close_timeout(str, optional): The total duration for this workflow execution. This overrides the defaultExecutionStartToCloseTimeout specified when registering the workflow type. The duration is specified in seconds; an integer greater than or equal to 0. Exceeding this limit causes the workflow execution to time out. Unlike some of the other timeout parameters in Amazon SWF, you cannot specify a value of "NONE" for this timeout; there is a one-year max limit on the time that a workflow execution can run.  An execution start-to-close timeout must be specified either through this parameter or as a default when the workflow type is registered. If neither this parameter nor a default execution start-to-close timeout is specified, a fault is returned. . Defaults to None.
        tag_list(List, optional): The list of tags to associate with the workflow execution. You can specify a maximum of 5 tags. You can list workflow executions with a specific tag by calling ListOpenWorkflowExecutions or ListClosedWorkflowExecutions and specifying a TagFilter. Defaults to None.
        task_start_to_close_timeout(str, optional): Specifies the maximum duration of decision tasks for this workflow execution. This parameter overrides the defaultTaskStartToCloseTimout specified when registering the workflow type using RegisterWorkflowType. The duration is specified in seconds, an integer greater than or equal to 0. You can use NONE to specify unlimited duration.  A task start-to-close timeout for this workflow execution must be specified either as a default for the workflow type or through this parameter. If neither this parameter is set nor a default task start-to-close timeout was specified at registration time then a fault is returned. . Defaults to None.
        child_policy(str, optional): If set, specifies the policy to use for the child workflow executions of this workflow execution if it is terminated, by calling the TerminateWorkflowExecution action explicitly or due to an expired timeout. This policy overrides the default child policy specified when registering the workflow type using RegisterWorkflowType. The supported child policies are:    TERMINATE – The child executions are terminated.    REQUEST_CANCEL – A request to cancel is attempted for each child execution by recording a WorkflowExecutionCancelRequested event in its history. It is up to the decider to take appropriate actions when it receives an execution history with this event.    ABANDON – No action is taken. The child executions continue to run.    A child policy for this workflow execution must be specified either as a default for the workflow type or through this parameter. If neither this parameter is set nor a default child policy was specified at registration time then a fault is returned. . Defaults to None.
        lambda_role(str, optional): The IAM role to attach to this workflow execution.  Executions of this workflow type need IAM roles to invoke Lambda functions. If you don't attach an IAM role, any attempt to schedule a Lambda task fails. This results in a ScheduleLambdaFunctionFailed history event. For more information, see https://docs.aws.amazon.com/amazonswf/latest/developerguide/lambda-task.html in the Amazon SWF Developer Guide. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.swf.workflow.execution.init.start(
                ctx, domain=value, workflow_id=value, workflow_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.swf.workflow.execution.init.start domain=value, workflow_id=value, workflow_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="swf",
        operation="start_workflow_execution",
        op_kwargs={
            "domain": domain,
            "workflowId": workflow_id,
            "workflowType": workflow_type,
            "taskList": task_list,
            "taskPriority": task_priority,
            "input": input_,
            "executionStartToCloseTimeout": execution_start_to_close_timeout,
            "tagList": tag_list,
            "taskStartToCloseTimeout": task_start_to_close_timeout,
            "childPolicy": child_policy,
            "lambdaRole": lambda_role,
        },
    )


async def terminate(
    hub,
    ctx,
    domain: str,
    workflow_id: str,
    run_id: str = None,
    reason: str = None,
    details: str = None,
    child_policy: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Records a WorkflowExecutionTerminated event and forces closure of the workflow execution identified by the given domain, runId, and workflowId. The child policy, registered with the workflow type or specified when starting this execution, is applied to any open child workflow executions of this workflow execution.  If the identified workflow execution was in progress, it is terminated immediately.   If a runId isn't specified, then the WorkflowExecutionTerminated event is recorded in the history of the current open workflow with the matching workflowId in the domain.   You should consider using RequestCancelWorkflowExecution action instead because it allows the workflow to gracefully close while TerminateWorkflowExecution doesn't.   Access Control  You can use IAM policies to control this action's access to Amazon SWF resources as follows:   Use a Resource element with the domain name to limit the action to only specified domains.   Use an Action element to allow or deny permission to call this action.   You cannot use an IAM policy to constrain this action's parameters.   If the caller doesn't have sufficient permissions to invoke the action, or the parameter values fall outside the specified constraints, the action fails. The associated event attribute's cause parameter is set to OPERATION_NOT_PERMITTED. For details and example IAM policies, see Using IAM to Manage Access to Amazon SWF Workflows in the Amazon SWF Developer Guide.

    Args:
        domain(str): The domain of the workflow execution to terminate.
        workflow_id(str): The workflowId of the workflow execution to terminate.
        run_id(str, optional): The runId of the workflow execution to terminate. Defaults to None.
        reason(str, optional):  A descriptive reason for terminating the workflow execution. Defaults to None.
        details(str, optional):  Details for terminating the workflow execution. Defaults to None.
        child_policy(str, optional): If set, specifies the policy to use for the child workflow executions of the workflow execution being terminated. This policy overrides the child policy specified for the workflow execution at registration time or when starting the execution. The supported child policies are:    TERMINATE – The child executions are terminated.    REQUEST_CANCEL – A request to cancel is attempted for each child execution by recording a WorkflowExecutionCancelRequested event in its history. It is up to the decider to take appropriate actions when it receives an execution history with this event.    ABANDON – No action is taken. The child executions continue to run.    A child policy for this workflow execution must be specified either as a default for the workflow type or through this parameter. If neither this parameter is set nor a default child policy was specified at registration time then a fault is returned. . Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.swf.workflow.execution.init.terminate(
                ctx, domain=value, workflow_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.swf.workflow.execution.init.terminate domain=value, workflow_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="swf",
        operation="terminate_workflow_execution",
        op_kwargs={
            "domain": domain,
            "workflowId": workflow_id,
            "runId": run_id,
            "reason": reason,
            "details": details,
            "childPolicy": child_policy,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def deregister(
    hub,
    ctx,
    transit_gateway_multicast_domain_id: str = None,
    group_ip_address: str = None,
    network_interface_ids: List = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Deregisters the specified sources (network interfaces) from the transit gateway multicast group.

    Args:
        transit_gateway_multicast_domain_id(str, optional): The ID of the transit gateway multicast domain. Defaults to None.
        group_ip_address(str, optional): The IP address assigned to the transit gateway multicast group. Defaults to None.
        network_interface_ids(List, optional): The IDs of the group sources' network interfaces. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.multicast.group.source.deregister(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.multicast.group.source.deregister
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="deregister_transit_gateway_multicast_group_sources",
        op_kwargs={
            "TransitGatewayMulticastDomainId": transit_gateway_multicast_domain_id,
            "GroupIpAddress": group_ip_address,
            "NetworkInterfaceIds": network_interface_ids,
            "DryRun": dry_run,
        },
    )


async def register(
    hub,
    ctx,
    transit_gateway_multicast_domain_id: str = None,
    group_ip_address: str = None,
    network_interface_ids: List = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Registers sources (network interfaces) with the specified transit gateway multicast group. A multicast source is a network interface attached to a supported instance that sends multicast traffic. For information about supported instances, see Multicast Considerations in Amazon VPC Transit Gateways. After you add the source, use SearchTransitGatewayMulticastGroups to verify that the source was added to the multicast group.

    Args:
        transit_gateway_multicast_domain_id(str, optional): The ID of the transit gateway multicast domain. Defaults to None.
        group_ip_address(str, optional): The IP address assigned to the transit gateway multicast group. Defaults to None.
        network_interface_ids(List, optional): The group sources' network interface IDs to register with the transit gateway multicast group. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.multicast.group.source.register(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.multicast.group.source.register
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="register_transit_gateway_multicast_group_sources",
        op_kwargs={
            "TransitGatewayMulticastDomainId": transit_gateway_multicast_domain_id,
            "GroupIpAddress": group_ip_address,
            "NetworkInterfaceIds": network_interface_ids,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(
    hub,
    ctx,
    deployment_type: str,
    service_name: str,
    spec: str,
    template_major_version: str = None,
    template_minor_version: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Update the service pipeline. There are four modes for updating a service pipeline as described in the following. The deploymentType field defines the mode.     NONE  In this mode, a deployment doesn't occur. Only the requested metadata parameters are updated.     CURRENT_VERSION  In this mode, the service pipeline is deployed and updated with the new spec that you provide. Only requested parameters are updated. Don’t include minor or major version parameters when you use this deployment-type.     MINOR_VERSION  In this mode, the service pipeline is deployed and updated with the published, recommended (latest) minor version of the current major version in use, by default. You can also specify a different minor version of the current major version in use.     MAJOR_VERSION  In this mode, the service pipeline is deployed and updated with the published, recommended (latest) major and minor version of the current template by default. You can also specify a different major version that is higher than the major version in use and a minor version (optional).

    Args:
        deployment_type(str): The deployment type. There are four modes for updating a service pipeline as described in the following. The deploymentType field defines the mode.     NONE  In this mode, a deployment doesn't occur. Only the requested metadata parameters are updated.     CURRENT_VERSION  In this mode, the service pipeline is deployed and updated with the new spec that you provide. Only requested parameters are updated. Don’t include minor or major version parameters when you use this deployment-type.     MINOR_VERSION  In this mode, the service pipeline is deployed and updated with the published, recommended (latest) minor version of the current major version in use, by default. You can also specify a different minor version of the current major version in use.     MAJOR_VERSION  In this mode, the service pipeline is deployed and updated with the published, recommended (latest) major and minor version of the current template, by default. You can also specify a different major version that is higher than the major version in use and a minor version (optional).  .
        service_name(str): The name of the service to that the pipeline is associated with.
        spec(str): The spec for the service pipeline to update.
        template_major_version(str, optional): The major version of the service template that was used to create the service that the pipeline is associated with. Defaults to None.
        template_minor_version(str, optional): The minor version of the service template that was used to create the service that the pipeline is associated with. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.proton.service.pipeline.init.update(
                ctx, deployment_type=value, service_name=value, spec=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.proton.service.pipeline.init.update deployment_type=value, service_name=value, spec=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="proton",
        operation="update_service_pipeline",
        op_kwargs={
            "deploymentType": deployment_type,
            "serviceName": service_name,
            "spec": spec,
            "templateMajorVersion": template_major_version,
            "templateMinorVersion": template_minor_version,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(
    hub,
    ctx,
    aws_account_id: str,
    dashboard_id: str,
    identity_type: str,
    session_lifetime_in_minutes: int = None,
    undo_redo_disabled: bool = None,
    reset_disabled: bool = None,
    state_persistence_enabled: bool = None,
    user_arn: str = None,
    namespace: str = None,
    additional_dashboard_ids: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Generates a session URL and authorization code that you can use to embed an Amazon QuickSight read-only dashboard in your web server code. Before you use this command, make sure that you have configured the dashboards and permissions.  Currently, you can use GetDashboardEmbedURL only from the server, not from the user's browser. The following rules apply to the combination of URL and authorization code:   They must be used together.   They can be used one time only.   They are valid for 5 minutes after you run this command.   The resulting user session is valid for 10 hours.   For more information, see Embedded Analytics in the Amazon QuickSight User Guide. For more information about the high-level steps for embedding and for an interactive demo of the ways you can customize embedding, visit the Amazon QuickSight Developer Portal.

    Args:
        aws_account_id(str): The ID for the Amazon Web Services account; that contains the dashboard that you're embedding.
        dashboard_id(str): The ID for the dashboard, also added to the Identity and Access Management (IAM) policy.
        identity_type(str): The authentication method that the user uses to sign in.
        session_lifetime_in_minutes(int, optional): How many minutes the session is valid. The session lifetime must be 15-600 minutes. Defaults to None.
        undo_redo_disabled(bool, optional): Remove the undo/redo button on the embedded dashboard. The default is FALSE, which enables the undo/redo button. Defaults to None.
        reset_disabled(bool, optional): Remove the reset button on the embedded dashboard. The default is FALSE, which enables the reset button. Defaults to None.
        state_persistence_enabled(bool, optional): Adds persistence of state for the user session in an embedded dashboard. Persistence applies to the sheet and the parameter settings. These are control settings that the dashboard subscriber (QuickSight reader) chooses while viewing the dashboard. If this is set to TRUE, the settings are the same when the subscriber reopens the same dashboard URL. The state is stored in QuickSight, not in a browser cookie. If this is set to FALSE, the state of the user session is not persisted. The default is FALSE. Defaults to None.
        user_arn(str, optional): The Amazon QuickSight user's Amazon Resource Name (ARN), for use with QUICKSIGHT identity type. You can use this for any Amazon QuickSight users in your account (readers, authors, or admins) authenticated as one of the following:   Active Directory (AD) users or group members   Invited nonfederated users   IAM users and IAM role-based sessions authenticated through Federated Single Sign-On using SAML, OpenID Connect, or IAM federation.   Omit this parameter for users in the third group – IAM users and IAM role-based sessions. Defaults to None.
        namespace(str, optional): The Amazon QuickSight namespace that the user virtually belongs to. If you are not using an Amazon QuickSight custom namespace, set this to default. Defaults to None.
        additional_dashboard_ids(List, optional): A list of one or more dashboard IDs that you want to add to a session that includes anonymous users. The IdentityType parameter must be set to ANONYMOUS for this to work, because other identity types authenticate as QuickSight or IAM users. For example, if you set "--dashboard-id dash_id1 --dashboard-id dash_id2 dash_id3 identity-type ANONYMOUS", the session can access all three dashboards. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.dashboard.embed_url.get(
                ctx, aws_account_id=value, dashboard_id=value, identity_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.dashboard.embed_url.get aws_account_id=value, dashboard_id=value, identity_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="get_dashboard_embed_url",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "DashboardId": dashboard_id,
            "IdentityType": identity_type,
            "SessionLifetimeInMinutes": session_lifetime_in_minutes,
            "UndoRedoDisabled": undo_redo_disabled,
            "ResetDisabled": reset_disabled,
            "StatePersistenceEnabled": state_persistence_enabled,
            "UserArn": user_arn,
            "Namespace": namespace,
            "AdditionalDashboardIds": additional_dashboard_ids,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(
    hub,
    ctx,
    service_update_name: str,
    replication_group_ids: List = None,
    cache_cluster_ids: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Apply the service update. For more information on service updates and applying them, see Applying Service Updates.

    Args:
        replication_group_ids(List, optional): The replication group IDs. Defaults to None.
        cache_cluster_ids(List, optional): The cache cluster IDs. Defaults to None.
        service_update_name(str): The unique ID of the service update.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticache.apply_update_action.batch(
                ctx, service_update_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticache.apply_update_action.batch service_update_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticache",
        operation="batch_apply_update_action",
        op_kwargs={
            "ReplicationGroupIds": replication_group_ids,
            "CacheClusterIds": cache_cluster_ids,
            "ServiceUpdateName": service_update_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    protocol: str = None,
    protocol_version: str = None,
    port: int = None,
    vpc_id: str = None,
    health_check_protocol: str = None,
    health_check_port: str = None,
    health_check_enabled: bool = None,
    health_check_path: str = None,
    health_check_interval_seconds: int = None,
    health_check_timeout_seconds: int = None,
    healthy_threshold_count: int = None,
    unhealthy_threshold_count: int = None,
    matcher: Dict = None,
    target_type: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a target group. For more information, see the following:    Target groups for your Application Load Balancers     Target groups for your Network Load Balancers     Target groups for your Gateway Load Balancers    This operation is idempotent, which means that it completes at most one time. If you attempt to create multiple target groups with the same settings, each call succeeds.

    Args:
        name(str): The name of the target group. This name must be unique per region per account, can have a maximum of 32 characters, must contain only alphanumeric characters or hyphens, and must not begin or end with a hyphen.
        protocol(str, optional): The protocol to use for routing traffic to the targets. For Application Load Balancers, the supported protocols are HTTP and HTTPS. For Network Load Balancers, the supported protocols are TCP, TLS, UDP, or TCP_UDP. For Gateway Load Balancers, the supported protocol is GENEVE. A TCP_UDP listener must be associated with a TCP_UDP target group. If the target is a Lambda function, this parameter does not apply. Defaults to None.
        protocol_version(str, optional): [HTTP/HTTPS protocol] The protocol version. Specify GRPC to send requests to targets using gRPC. Specify HTTP2 to send requests to targets using HTTP/2. The default is HTTP1, which sends requests to targets using HTTP/1.1. Defaults to None.
        port(int, optional): The port on which the targets receive traffic. This port is used unless you specify a port override when registering the target. If the target is a Lambda function, this parameter does not apply. If the protocol is GENEVE, the supported port is 6081. Defaults to None.
        vpc_id(str, optional): The identifier of the virtual private cloud (VPC). If the target is a Lambda function, this parameter does not apply. Otherwise, this parameter is required. Defaults to None.
        health_check_protocol(str, optional): The protocol the load balancer uses when performing health checks on targets. For Application Load Balancers, the default is HTTP. For Network Load Balancers and Gateway Load Balancers, the default is TCP. The TCP protocol is not supported for health checks if the protocol of the target group is HTTP or HTTPS. The GENEVE, TLS, UDP, and TCP_UDP protocols are not supported for health checks. Defaults to None.
        health_check_port(str, optional): The port the load balancer uses when performing health checks on targets. If the protocol is HTTP, HTTPS, TCP, TLS, UDP, or TCP_UDP, the default is traffic-port, which is the port on which each target receives traffic from the load balancer. If the protocol is GENEVE, the default is port 80. Defaults to None.
        health_check_enabled(bool, optional): Indicates whether health checks are enabled. If the target type is lambda, health checks are disabled by default but can be enabled. If the target type is instance or ip, health checks are always enabled and cannot be disabled. Defaults to None.
        health_check_path(str, optional): [HTTP/HTTPS health checks] The destination for health checks on the targets. [HTTP1 or HTTP2 protocol version] The ping path. The default is /. [GRPC protocol version] The path of a custom health check method with the format /package.service/method. The default is /Amazon Web Services.ALB/healthcheck. Defaults to None.
        health_check_interval_seconds(int, optional): The approximate amount of time, in seconds, between health checks of an individual target. If the target group protocol is TCP, TLS, UDP, or TCP_UDP, the supported values are 10 and 30 seconds. If the target group protocol is HTTP or HTTPS, the default is 30 seconds. If the target group protocol is GENEVE, the default is 10 seconds. If the target type is lambda, the default is 35 seconds. Defaults to None.
        health_check_timeout_seconds(int, optional): The amount of time, in seconds, during which no response from a target means a failed health check. For target groups with a protocol of HTTP, HTTPS, or GENEVE, the default is 5 seconds. For target groups with a protocol of TCP or TLS, this value must be 6 seconds for HTTP health checks and 10 seconds for TCP and HTTPS health checks. If the target type is lambda, the default is 30 seconds. Defaults to None.
        healthy_threshold_count(int, optional): The number of consecutive health checks successes required before considering an unhealthy target healthy. For target groups with a protocol of HTTP or HTTPS, the default is 5. For target groups with a protocol of TCP, TLS, or GENEVE, the default is 3. If the target type is lambda, the default is 5. Defaults to None.
        unhealthy_threshold_count(int, optional): The number of consecutive health check failures required before considering a target unhealthy. If the target group protocol is HTTP or HTTPS, the default is 2. If the target group protocol is TCP or TLS, this value must be the same as the healthy threshold count. If the target group protocol is GENEVE, the default is 3. If the target type is lambda, the default is 2. Defaults to None.
        matcher(Dict, optional): [HTTP/HTTPS health checks] The HTTP or gRPC codes to use when checking for a successful response from a target. Defaults to None.
        target_type(str, optional): The type of target that you must specify when registering targets with this target group. You can't specify targets for a target group using more than one target type.    instance - Register targets by instance ID. This is the default value.    ip - Register targets by IP address. You can specify IP addresses from the subnets of the virtual private cloud (VPC) for the target group, the RFC 1918 range (10.0.0.0/8, 172.16.0.0/12, and 192.168.0.0/16), and the RFC 6598 range (100.64.0.0/10). You can't specify publicly routable IP addresses.    lambda - Register a single Lambda function as a target.  . Defaults to None.
        tags(List, optional): The tags to assign to the target group. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elbv2.target.group.init.create(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elbv2.target.group.init.create name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elbv2",
        operation="create_target_group",
        op_kwargs={
            "Name": name,
            "Protocol": protocol,
            "ProtocolVersion": protocol_version,
            "Port": port,
            "VpcId": vpc_id,
            "HealthCheckProtocol": health_check_protocol,
            "HealthCheckPort": health_check_port,
            "HealthCheckEnabled": health_check_enabled,
            "HealthCheckPath": health_check_path,
            "HealthCheckIntervalSeconds": health_check_interval_seconds,
            "HealthCheckTimeoutSeconds": health_check_timeout_seconds,
            "HealthyThresholdCount": healthy_threshold_count,
            "UnhealthyThresholdCount": unhealthy_threshold_count,
            "Matcher": matcher,
            "TargetType": target_type,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, target_group_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified target group. You can delete a target group if it is not referenced by any actions. Deleting a target group also deletes any associated health checks. Deleting a target group does not affect its registered targets. For example, any EC2 instances continue to run until you stop or terminate them.

    Args:
        target_group_arn(str): The Amazon Resource Name (ARN) of the target group.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elbv2.target.group.init.delete(ctx, target_group_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elbv2.target.group.init.delete target_group_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elbv2",
        operation="delete_target_group",
        op_kwargs={"TargetGroupArn": target_group_arn},
    )


async def describe_all(
    hub,
    ctx,
    load_balancer_arn: str = None,
    target_group_arns: List = None,
    names: List = None,
    marker: str = None,
    page_size: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified target groups or all of your target groups. By default, all target groups are described. Alternatively, you can specify one of the following to filter the results: the ARN of the load balancer, the names of one or more target groups, or the ARNs of one or more target groups.

    Args:
        load_balancer_arn(str, optional): The Amazon Resource Name (ARN) of the load balancer. Defaults to None.
        target_group_arns(List, optional): The Amazon Resource Names (ARN) of the target groups. Defaults to None.
        names(List, optional): The names of the target groups. Defaults to None.
        marker(str, optional): The marker for the next set of results. (You received this marker from a previous call.). Defaults to None.
        page_size(int, optional): The maximum number of results to return with this call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elbv2.target.group.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elbv2.target.group.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elbv2",
        operation="describe_target_groups",
        op_kwargs={
            "LoadBalancerArn": load_balancer_arn,
            "TargetGroupArns": target_group_arns,
            "Names": names,
            "Marker": marker,
            "PageSize": page_size,
        },
    )


async def modify(
    hub,
    ctx,
    target_group_arn: str,
    health_check_protocol: str = None,
    health_check_port: str = None,
    health_check_path: str = None,
    health_check_enabled: bool = None,
    health_check_interval_seconds: int = None,
    health_check_timeout_seconds: int = None,
    healthy_threshold_count: int = None,
    unhealthy_threshold_count: int = None,
    matcher: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the health checks used when evaluating the health state of the targets in the specified target group.

    Args:
        target_group_arn(str): The Amazon Resource Name (ARN) of the target group.
        health_check_protocol(str, optional): The protocol the load balancer uses when performing health checks on targets. For Application Load Balancers, the default is HTTP. For Network Load Balancers and Gateway Load Balancers, the default is TCP. The TCP protocol is not supported for health checks if the protocol of the target group is HTTP or HTTPS. It is supported for health checks only if the protocol of the target group is TCP, TLS, UDP, or TCP_UDP. The GENEVE, TLS, UDP, and TCP_UDP protocols are not supported for health checks. With Network Load Balancers, you can't modify this setting. Defaults to None.
        health_check_port(str, optional): The port the load balancer uses when performing health checks on targets. Defaults to None.
        health_check_path(str, optional): [HTTP/HTTPS health checks] The destination for health checks on the targets. [HTTP1 or HTTP2 protocol version] The ping path. The default is /. [GRPC protocol version] The path of a custom health check method with the format /package.service/method. The default is /Amazon Web Services.ALB/healthcheck. Defaults to None.
        health_check_enabled(bool, optional): Indicates whether health checks are enabled. Defaults to None.
        health_check_interval_seconds(int, optional): The approximate amount of time, in seconds, between health checks of an individual target. For TCP health checks, the supported values are 10 or 30 seconds. With Network Load Balancers, you can't modify this setting. Defaults to None.
        health_check_timeout_seconds(int, optional): [HTTP/HTTPS health checks] The amount of time, in seconds, during which no response means a failed health check. With Network Load Balancers, you can't modify this setting. Defaults to None.
        healthy_threshold_count(int, optional): The number of consecutive health checks successes required before considering an unhealthy target healthy. Defaults to None.
        unhealthy_threshold_count(int, optional): The number of consecutive health check failures required before considering the target unhealthy. For target groups with a protocol of TCP or TLS, this value must be the same as the healthy threshold count. Defaults to None.
        matcher(Dict, optional): [HTTP/HTTPS health checks] The HTTP or gRPC codes to use when checking for a successful response from a target. With Network Load Balancers, you can't modify this setting. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elbv2.target.group.init.modify(ctx, target_group_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elbv2.target.group.init.modify target_group_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elbv2",
        operation="modify_target_group",
        op_kwargs={
            "TargetGroupArn": target_group_arn,
            "HealthCheckProtocol": health_check_protocol,
            "HealthCheckPort": health_check_port,
            "HealthCheckPath": health_check_path,
            "HealthCheckEnabled": health_check_enabled,
            "HealthCheckIntervalSeconds": health_check_interval_seconds,
            "HealthCheckTimeoutSeconds": health_check_timeout_seconds,
            "HealthyThresholdCount": healthy_threshold_count,
            "UnhealthyThresholdCount": unhealthy_threshold_count,
            "Matcher": matcher,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, crawler_names: List) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of resource metadata for a given list of crawler names. After calling the ListCrawlers operation, you can call this operation to access the data to which you have been granted permissions. This operation supports all IAM permissions, including permission conditions that uses tags.

    Args:
        crawler_names(List): A list of crawler names, which might be the names returned from the ListCrawlers operation.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.get.crawler.batch(ctx, crawler_names=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.get.crawler.batch crawler_names=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="batch_get_crawlers",
        op_kwargs={"CrawlerNames": crawler_names},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, restore_job_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns metadata associated with a restore job that is specified by a job ID.

    Args:
        restore_job_id(str): Uniquely identifies the job that restores a recovery point.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.restore_job.describe(ctx, restore_job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.restore_job.describe restore_job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="backup",
        operation="describe_restore_job",
        op_kwargs={"RestoreJobId": restore_job_id},
    )


async def list_all(
    hub,
    ctx,
    next_token: str = None,
    max_results: int = None,
    by_account_id: str = None,
    by_created_before: str = None,
    by_created_after: str = None,
    by_status: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of jobs that AWS Backup initiated to restore a saved resource, including metadata about the recovery process.

    Args:
        next_token(str, optional): The next item following a partial list of returned items. For example, if a request is made to return maxResults number of items, NextToken allows you to return more items in your list starting at the location pointed to by the next token. Defaults to None.
        max_results(int, optional): The maximum number of items to be returned. Defaults to None.
        by_account_id(str, optional): The account ID to list the jobs from. Returns only restore jobs associated with the specified account ID. Defaults to None.
        by_created_before(str, optional): Returns only restore jobs that were created before the specified date. Defaults to None.
        by_created_after(str, optional): Returns only restore jobs that were created after the specified date. Defaults to None.
        by_status(str, optional): Returns only restore jobs associated with the specified job status. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.restore_job.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.restore_job.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="backup",
        operation="list_restore_jobs",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "ByAccountId": by_account_id,
            "ByCreatedBefore": by_created_before,
            "ByCreatedAfter": by_created_after,
            "ByStatus": by_status,
        },
    )


async def start(
    hub,
    ctx,
    recovery_point_arn: str,
    metadata: Dict,
    iam_role_arn: str,
    idempotency_token: str = None,
    resource_type: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Recovers the saved resource identified by an Amazon Resource Name (ARN).

    Args:
        recovery_point_arn(str): An ARN that uniquely identifies a recovery point; for example, arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45.
        metadata(Dict): A set of metadata key-value pairs. Contains information, such as a resource name, required to restore a recovery point.  You can get configuration metadata about a resource at the time it was backed up by calling GetRecoveryPointRestoreMetadata. However, values in addition to those provided by GetRecoveryPointRestoreMetadata might be required to restore a resource. For example, you might need to provide a new resource name if the original already exists. You need to specify specific metadata to restore an Amazon Elastic File System (Amazon EFS) instance:    file-system-id: The ID of the Amazon EFS file system that is backed up by AWS Backup. Returned in GetRecoveryPointRestoreMetadata.    Encrypted: A Boolean value that, if true, specifies that the file system is encrypted. If KmsKeyId is specified, Encrypted must be set to true.    KmsKeyId: Specifies the AWS KMS key that is used to encrypt the restored file system. You can specify a key from another AWS account provided that key it is properly shared with your account via AWS KMS.    PerformanceMode: Specifies the throughput mode of the file system.    CreationToken: A user-supplied value that ensures the uniqueness (idempotency) of the request.    newFileSystem: A Boolean value that, if true, specifies that the recovery point is restored to a new Amazon EFS file system.    ItemsToRestore : An array of one to five strings where each string is a file path. Use ItemsToRestore to restore specific files or directories rather than the entire file system. This parameter is optional. For example, "itemsToRestore":"[\"/my.test\"]".  .
        iam_role_arn(str): The Amazon Resource Name (ARN) of the IAM role that AWS Backup uses to create the target recovery point; for example, arn:aws:iam::123456789012:role/S3Access.
        idempotency_token(str, optional): A customer chosen string that can be used to distinguish between calls to StartRestoreJob. Defaults to None.
        resource_type(str, optional): Starts a job to restore a recovery point for one of the following resources:    DynamoDB for Amazon DynamoDB    EBS for Amazon Elastic Block Store    EC2 for Amazon Elastic Compute Cloud    EFS for Amazon Elastic File System    RDS for Amazon Relational Database Service    Aurora for Amazon Aurora    Storage Gateway for AWS Storage Gateway  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.restore_job.start(
                ctx, recovery_point_arn=value, metadata=value, iam_role_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.restore_job.start recovery_point_arn=value, metadata=value, iam_role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="backup",
        operation="start_restore_job",
        op_kwargs={
            "RecoveryPointArn": recovery_point_arn,
            "Metadata": metadata,
            "IamRoleArn": iam_role_arn,
            "IdempotencyToken": idempotency_token,
            "ResourceType": resource_type,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete_multiple(
    hub, ctx, folder_id: str, authentication_token: str = None
) -> None:
    r"""
    **Autogenerated function**

    Deletes the contents of the specified folder.

    Args:
        authentication_token(str, optional): Amazon WorkDocs authentication token. Not required when using AWS administrator credentials to access the API. Defaults to None.
        folder_id(str): The ID of the folder.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workdoc.folder.content.delete_multiple(ctx, folder_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workdoc.folder.content.delete_multiple folder_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workdocs",
        operation="delete_folder_contents",
        op_kwargs={"AuthenticationToken": authentication_token, "FolderId": folder_id},
    )


async def describe_all(
    hub,
    ctx,
    folder_id: str,
    authentication_token: str = None,
    sort: str = None,
    order: str = None,
    limit: int = None,
    marker: str = None,
    type_: str = None,
    include: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the contents of the specified folder, including its documents and subfolders. By default, Amazon WorkDocs returns the first 100 active document and folder metadata items. If there are more results, the response includes a marker that you can use to request the next set of results. You can also request initialized documents.

    Args:
        authentication_token(str, optional): Amazon WorkDocs authentication token. Not required when using AWS administrator credentials to access the API. Defaults to None.
        folder_id(str): The ID of the folder.
        sort(str, optional): The sorting criteria. Defaults to None.
        order(str, optional): The order for the contents of the folder. Defaults to None.
        limit(int, optional): The maximum number of items to return with this call. Defaults to None.
        marker(str, optional): The marker for the next set of results. This marker was received from a previous call. Defaults to None.
        type_(str, optional): The type of items. Defaults to None.
        include(str, optional): The contents to include. Specify "INITIALIZED" to include initialized documents. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workdoc.folder.content.describe_all(ctx, folder_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workdoc.folder.content.describe_all folder_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workdocs",
        operation="describe_folder_contents",
        op_kwargs={
            "AuthenticationToken": authentication_token,
            "FolderId": folder_id,
            "Sort": sort,
            "Order": order,
            "Limit": limit,
            "Marker": marker,
            "Type": type_,
            "Include": include,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get_all(
    hub, ctx, resource_types: List = None, limit: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the resource types, the number of each resource type, and the total number of resources that AWS Config is recording in this region for your AWS account.   Example    AWS Config is recording three resource types in the US East (Ohio) Region for your account: 25 EC2 instances, 20 IAM users, and 15 S3 buckets.   You make a call to the GetDiscoveredResourceCounts action and specify that you want all resource types.    AWS Config returns the following:   The resource types (EC2 instances, IAM users, and S3 buckets).   The number of each resource type (25, 20, and 15).   The total number of all resources (60).     The response is paginated. By default, AWS Config lists 100 ResourceCount objects on each page. You can customize this number with the limit parameter. The response includes a nextToken string. To get the next page of results, run the request again and specify the string for the nextToken parameter.  If you make a call to the GetDiscoveredResourceCounts action, you might not immediately receive resource counts in the following situations:   You are a new AWS Config customer.   You just enabled resource recording.   It might take a few minutes for AWS Config to record and count your resources. Wait a few minutes and then retry the GetDiscoveredResourceCounts action.

    Args:
        resource_types(List, optional): The comma-separated list that specifies the resource types that you want AWS Config to return (for example, "AWS::EC2::Instance", "AWS::IAM::User"). If a value for resourceTypes is not specified, AWS Config returns all resource types that AWS Config is recording in the region for your account.  If the configuration recorder is turned off, AWS Config returns an empty list of ResourceCount objects. If the configuration recorder is not recording a specific resource type (for example, S3 buckets), that resource type is not returned in the list of ResourceCount objects. . Defaults to None.
        limit(int, optional): The maximum number of ResourceCount objects returned on each page. The default is 100. You cannot specify a number greater than 100. If you specify 0, AWS Config uses the default. Defaults to None.
        next_token(str, optional): The nextToken string returned on a previous page that you use to get the next page of results in a paginated response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.discovered_resource.count.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.discovered_resource.count.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="get_discovered_resource_counts",
        op_kwargs={
            "resourceTypes": resource_types,
            "limit": limit,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"set_": "set"}


async def describe(hub, ctx, instance_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Describes time-based auto scaling configurations for specified instances.  You must specify at least one of the parameters.   Required Permissions: To use this action, an IAM user must have a Show, Deploy, or Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information about user permissions, see Managing User Permissions.

    Args:
        instance_ids(List): An array of instance IDs.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.time_based_auto_scaling.describe(
                ctx, instance_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.time_based_auto_scaling.describe instance_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="describe_time_based_auto_scaling",
        op_kwargs={"InstanceIds": instance_ids},
    )


async def set_(hub, ctx, instance_id: str, auto_scaling_schedule: Dict = None) -> None:
    r"""
    **Autogenerated function**

    Specify the time-based auto scaling configuration for a specified instance. For more information, see Managing Load with Time-based and Load-based Instances.  Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information on user permissions, see Managing User Permissions.

    Args:
        instance_id(str): The instance ID.
        auto_scaling_schedule(Dict, optional): An AutoScalingSchedule with the instance schedule. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.time_based_auto_scaling.set(ctx, instance_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.time_based_auto_scaling.set instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="set_time_based_auto_scaling",
        op_kwargs={
            "InstanceId": instance_id,
            "AutoScalingSchedule": auto_scaling_schedule,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    transit_gateway_attachment_id: str,
    peer_address: str,
    inside_cidr_blocks: List,
    transit_gateway_address: str = None,
    bgp_options: Dict = None,
    tag_specifications: List = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a Connect peer for a specified transit gateway Connect attachment between a transit gateway and an appliance. The peer address and transit gateway address must be the same IP address family (IPv4 or IPv6). For more information, see Connect peers in the Transit Gateways Guide.

    Args:
        transit_gateway_attachment_id(str): The ID of the Connect attachment.
        transit_gateway_address(str, optional): The peer IP address (GRE outer IP address) on the transit gateway side of the Connect peer, which must be specified from a transit gateway CIDR block. If not specified, Amazon automatically assigns the first available IP address from the transit gateway CIDR block. Defaults to None.
        peer_address(str): The peer IP address (GRE outer IP address) on the appliance side of the Connect peer.
        bgp_options(Dict, optional): The BGP options for the Connect peer. Defaults to None.
        inside_cidr_blocks(List): The range of inside IP addresses that are used for BGP peering. You must specify a size /29 IPv4 CIDR block from the 169.254.0.0/16 range. The first address from the range must be configured on the appliance as the BGP IP address. You can also optionally specify a size /125 IPv6 CIDR block from the fd00::/8 range.
        tag_specifications(List, optional): The tags to apply to the Connect peer. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.connect.peer.create(
                ctx,
                transit_gateway_attachment_id=value,
                peer_address=value,
                inside_cidr_blocks=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.connect.peer.create transit_gateway_attachment_id=value, peer_address=value, inside_cidr_blocks=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_transit_gateway_connect_peer",
        op_kwargs={
            "TransitGatewayAttachmentId": transit_gateway_attachment_id,
            "TransitGatewayAddress": transit_gateway_address,
            "PeerAddress": peer_address,
            "BgpOptions": bgp_options,
            "InsideCidrBlocks": inside_cidr_blocks,
            "TagSpecifications": tag_specifications,
            "DryRun": dry_run,
        },
    )


async def delete(
    hub, ctx, transit_gateway_connect_peer_id: str, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified Connect peer.

    Args:
        transit_gateway_connect_peer_id(str): The ID of the Connect peer.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.connect.peer.delete(
                ctx, transit_gateway_connect_peer_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.connect.peer.delete transit_gateway_connect_peer_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_transit_gateway_connect_peer",
        op_kwargs={
            "TransitGatewayConnectPeerId": transit_gateway_connect_peer_id,
            "DryRun": dry_run,
        },
    )


async def describe_all(
    hub,
    ctx,
    transit_gateway_connect_peer_ids: List = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes one or more Connect peers.

    Args:
        transit_gateway_connect_peer_ids(List, optional): The IDs of the Connect peers. Defaults to None.
        filters(List, optional): One or more filters. The possible values are:    state - The state of the Connect peer (pending | available | deleting | deleted).    transit-gateway-attachment-id - The ID of the attachment.    transit-gateway-connect-peer-id - The ID of the Connect peer.  . Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.connect.peer.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.connect.peer.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_transit_gateway_connect_peers",
        op_kwargs={
            "TransitGatewayConnectPeerIds": transit_gateway_connect_peer_ids,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: List) -> Dict:
    r"""
    **Autogenerated function**

    Associates a specific tag with an Amazon Comprehend resource. A tag is a key-value pair that adds as a metadata to a resource used by Amazon Comprehend. For example, a tag with "Sales" as the key might be added to a resource to indicate its use by the sales department.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the given Amazon Comprehend resource to which you want to associate the tags. .
        tags(List): Tags being associated with a specific Amazon Comprehend resource. There can be a maximum of 50 tags (both existing and pending) associated with a specific resource. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehend.resource.tag(ctx, resource_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehend.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehend",
        operation="tag_resource",
        op_kwargs={"ResourceArn": resource_arn, "Tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes a specific tag associated with an Amazon Comprehend resource.

    Args:
        resource_arn(str):  The Amazon Resource Name (ARN) of the given Amazon Comprehend resource from which you want to remove the tags. .
        tag_keys(List): The initial part of a key-value pair that forms a tag being removed from a given resource. For example, a tag with "Sales" as the key might be added to a resource to indicate its use by the sales department. Keys must be unique and cannot be duplicated for a particular resource. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehend.resource.untag(
                ctx, resource_arn=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehend.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehend",
        operation="untag_resource",
        op_kwargs={"ResourceArn": resource_arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def accept(hub, ctx, shared_directory_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Accepts a directory sharing request that was sent from the directory owner account.

    Args:
        shared_directory_id(str): Identifier of the shared directory in the directory consumer account. This identifier is different for each directory owner account. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.shared_directory.accept(ctx, shared_directory_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.shared_directory.accept shared_directory_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="accept_shared_directory",
        op_kwargs={"SharedDirectoryId": shared_directory_id},
    )


async def describe_all(
    hub,
    ctx,
    owner_directory_id: str,
    shared_directory_ids: List = None,
    next_token: str = None,
    limit: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the shared directories in your account.

    Args:
        owner_directory_id(str): Returns the identifier of the directory in the directory owner account. .
        shared_directory_ids(List, optional): A list of identifiers of all shared directories in your account. . Defaults to None.
        next_token(str, optional): The DescribeSharedDirectoriesResult.NextToken value from a previous call to DescribeSharedDirectories. Pass null if this is the first call. . Defaults to None.
        limit(int, optional): The number of shared directories to return in the response object. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.shared_directory.describe_all(ctx, owner_directory_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.shared_directory.describe_all owner_directory_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="describe_shared_directories",
        op_kwargs={
            "OwnerDirectoryId": owner_directory_id,
            "SharedDirectoryIds": shared_directory_ids,
            "NextToken": next_token,
            "Limit": limit,
        },
    )


async def reject(hub, ctx, shared_directory_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Rejects a directory sharing request that was sent from the directory owner account.

    Args:
        shared_directory_id(str): Identifier of the shared directory in the directory consumer account. This identifier is different for each directory owner account.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.shared_directory.reject(ctx, shared_directory_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.shared_directory.reject shared_directory_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="reject_shared_directory",
        op_kwargs={"SharedDirectoryId": shared_directory_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, account_id: str, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Indicates whether the specified access point currently has a policy that allows public access. For more information about public access through access points, see Managing Data Access with Amazon S3 access points in the Amazon S3 User Guide.

    Args:
        account_id(str): The account ID for the account that owns the specified access point.
        name(str): The name of the access point whose policy status you want to retrieve.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.access_point.policy.status.init.get(
                ctx, account_id=value, name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.access_point.policy.status.init.get account_id=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="get_access_point_policy_status",
        op_kwargs={"AccountId": account_id, "Name": name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    alias_ids: List = None,
    resource_id: str = None,
    limit: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list that describes the connection aliases used for cross-Region redirection. For more information, see  Cross-Region Redirection for Amazon WorkSpaces.

    Args:
        alias_ids(List, optional): The identifiers of the connection aliases to describe. Defaults to None.
        resource_id(str, optional): The identifier of the directory associated with the connection alias. Defaults to None.
        limit(int, optional): The maximum number of connection aliases to return. Defaults to None.
        next_token(str, optional): If you received a NextToken from a previous call that was paginated, provide this token to receive the next set of results. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.connection_aliase.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.connection_aliase.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="describe_connection_aliases",
        op_kwargs={
            "AliasIds": alias_ids,
            "ResourceId": resource_id,
            "Limit": limit,
            "NextToken": next_token,
        },
    )
